・DS特論（3年次1学期）の授業にてPyPIで公開した

https://pypi.org/project/online-scheduler/

・実行例

初回の実行時にURLを格納するurl.csvを一度作成する。その後の起動でurl.csvに格納されているURLをブラウザで開くかurl.csvのURLを編集するか選択できるようになる。

下の画像ではschedule.pyというファイルにonline_schedulerをインポートして動かしている。

<img width="242" alt="image" src="online_scheduler/test.png">

このファイルのコードは下の画像の通りである。

<img width="242" alt="image" src="online_scheduler/schedule_code.png">
